@@ -394,7 +394,7 @@ func (p *RegistryProvider) Get(namespace, name string) (*operators.PackageManife
 		"namespace": namespace,
 	})
 
-	pkgs, err := p.List(namespace)
+	pkgs, err := p.List(namespace, labels.Everything())
 	if err != nil {
 		return nil, fmt.Errorf("could not list packages in namespace %s", namespace)
 	}
@@ -409,23 +409,23 @@ func (p *RegistryProvider) Get(namespace, name string) (*operators.PackageManife
 	return nil, nil
 }
 
-func (p *RegistryProvider) List(namespace string) (*operators.PackageManifestList, error) {
+func (p *RegistryProvider) List(namespace string, selector labels.Selector) (*operators.PackageManifestList, error) {
 	var pkgs []*operators.PackageManifest
 	if namespace == metav1.NamespaceAll {
-		all, err := p.pkgLister.List(labels.Everything())
+		all, err := p.pkgLister.List(selector)
 		if err != nil {
 			return nil, err
 		}
 		pkgs = append(pkgs, all...)
 	} else {
-		nsPkgs, err := p.pkgLister.PackageManifests(namespace).List(labels.Everything())
+		nsPkgs, err := p.pkgLister.PackageManifests(namespace).List(selector)
 		if err != nil {
 			return nil, err
 		}
 		pkgs = append(pkgs, nsPkgs...)
 
 		if namespace != p.globalNamespace {
-			globalPkgs, err := p.pkgLister.PackageManifests(p.globalNamespace).List(labels.Everything())
+			globalPkgs, err := p.pkgLister.PackageManifests(p.globalNamespace).List(selector)
 			if err != nil {
 				return nil, err
 			}
@@ -488,6 +488,11 @@ func newPackageManifest(ctx context.Context, logger *logrus.Entry, pkg *api.Pack
 			defaultElided = defaultElided || pkgChannel.Name == manifest.Status.DefaultChannel
 			continue
 		}
+		manifestLabels := manifest.GetLabels()
+		for k, v := range csv.GetLabels() {
+			manifestLabels[k] = v
+		}
+		manifest.SetLabels(manifest.GetLabels())
 		manifest.Status.Channels = append(manifest.Status.Channels, operators.PackageChannel{
 			Name:           pkgChannel.GetName(),
 			CurrentCSV:     csv.GetName(),
